==> haskell-pgp-wordlist-0.1.0.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pgp-wordlist
version: 0.1.0.3
id: pgp-wordlist-0.1.0.3-H9v1dHRvnyk6SfoZweW3Zz
key: pgp-wordlist-0.1.0.3-H9v1dHRvnyk6SfoZweW3Zz
license: BSD-3-Clause
copyright: David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer: David Luposchainsky <dluposchainsky(λ)gmail.com>
author: David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage: https://github.com/quchen/pgp-wordlist
synopsis: Translate between binary data and a human-readable
          collection of words.
description:
    Translate between binary data and a human-readable
    collection of words.
    .
    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.
    .
    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.
    .
    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.
category: Data, Serialization
abi: f458e0d4f1fb8acb8dd3aa206a406f5c
exposed: True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words
import-dirs: /usr/lib/ghc-8.6.5/site-local/pgp-wordlist-0.1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/pgp-wordlist-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pgp-wordlist-0.1.0.3
hs-libraries: HSpgp-wordlist-0.1.0.3-H9v1dHRvnyk6SfoZweW3Zz
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock
haddock-html: /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pgp-wordlist-0.1.0.3-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pgp-wordlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pgp-wordlist
version: 0.1.0.3
id: pgp-wordlist-0.1.0.3-VV0U6osqcOHg7a9BrDO30
key: pgp-wordlist-0.1.0.3-VV0U6osqcOHg7a9BrDO30
license: BSD-3-Clause
copyright: David Luposchainsky <dluposchainsky(λ)gmail.com>
maintainer: David Luposchainsky <dluposchainsky(λ)gmail.com>
author: David Luposchainsky <dluposchainsky(λ)gmail.com>
homepage: https://github.com/quchen/pgp-wordlist
synopsis: Translate between binary data and a human-readable
          collection of words.
description:
    Translate between binary data and a human-readable
    collection of words.
    .
    The PGP Word List consists of two phonetic alphabets, each
    with one word per possible byte value. A string of bytes
    is translated with these alphabets, alternating between
    them at each byte.
    .
    The PGP words corresponding to the bytes @5B 1D CA 6E@
    are "erase breakaway spellbind headwaters", for example.
    .
    For further information, see
    <http://en.wikipedia.org/wiki/PGP_word_list Wikipedia>.
category: Data, Serialization
abi: 3b3d29b0bea87b6a2b0ad4722efcc7a9
exposed: True
exposed-modules:
    Data.Text.PgpWordlist Data.Text.PgpWordlist.Internal.AltList
    Data.Text.PgpWordlist.Internal.Convert
    Data.Text.PgpWordlist.Internal.Types
    Data.Text.PgpWordlist.Internal.Word8Bimap
    Data.Text.PgpWordlist.Internal.Words
import-dirs: /usr/lib/ghc-8.6.5/site-local/pgp-wordlist-0.1.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/pgp-wordlist-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pgp-wordlist-0.1.0.3
hs-libraries: HSpgp-wordlist-0.1.0.3-VV0U6osqcOHg7a9BrDO30
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-pgp-wordlist/html/pgp-wordlist.haddock
haddock-html: /usr/share/doc/haskell-pgp-wordlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
